# cashlog

[![GitHub main workflow](https://img.shields.io/github/actions/workflow/status/dmotte/cashlog/main.yml?branch=main&logo=github&label=main&style=flat-square)](https://github.com/dmotte/cashlog/actions)
[![PyPI](https://img.shields.io/pypi/v/cashlog?logo=python&style=flat-square)](https://pypi.org/project/cashlog/)

:snake: **Cash** flow **tracker**.

TODO write the README
